==> projectx-sdk-1.0.72-sources.jar: cn/com/duiba/projectx/sdk/ErrorCode.java <==
package cn.com.duiba.projectx.sdk;

public class ErrorCode {

    /**
     * 未知异常
     */
    public static final Integer ERR_10000 = 100000;
    public static final String ERR_10000_MSG = "未知异常";
    /**
     * 未登录
     */
    public static final Integer ERR_10001 = 100001;
    /**
     * 活动未开始
     */
    public static final Integer ERR_10002 = 100002;
    /**
     * 活动已结束
     */
    public static final Integer ERR_10003 = 100003;
    /**
     * 活动异常
     */
    public static final Integer ERR_10004 = 100004;
    /**
     * 前置校验失败
     */
    public static final Integer ERR_10005 = 100005;
    /**
     * 门票校验失败
     */
    public static final Integer ERR_10006 = 100006;
    /**
     * 无权访问，定向APP
     */
    public static final Integer ERR_10007 = 100007;
    /**
     * Not Found
     */
    public static final Integer ERR_10008 = 100008;

    /**
     * 不允许openBs访问
     */
    public static final Integer ERR_10009 = 100009;

    /**
     * 生成邀请码失败
     */
    public static final Integer ERR_10010 = 100010;

    /**
     * 邀请码不存在
     */
    public static final Integer ERR_10011 = 100011;

    /**
     * 已经接受邀请
     */
    public static final Integer ERR_10012 = 100012;

    /**
     * 邀请码异常
     */
    public static final Integer ERR_10013 = 100013;

    /**
     * 不能邀请自己
     */
    public static final Integer ERR_10014 = 100014;

    /**
     * 已经过接受邀请
     */
    public static final Integer ERR_10015 = 100015;

    /**
     * 库存限制
     */
    public static final Integer ERR_10016 = 100016;

    /**
     * 参数校验失败
     */
    public static final Integer ERR_10017 = 100017;

    /**
     * 风控异常
     */
    public static final Integer ERR_10018 = 100018;

    /**
     * 非法助力itemId
     */
    public static final Integer ERR_10019 = 100019;

    /**
     * 不能给自己助力
     */
    public static final Integer ERR_100020 = 100020;

    /**
     * 方法不存在
     */
    public static final Integer ERR_10021 = 100021;

    /**
     * Token为空
     */
    public static final Integer ERR_100022 = 100022;

    /**
     * 无效Token
     */
    public static final Integer ERR_100023 = 100023;

    /**
     * token key失效
     */
    public static final Integer ERR_100024 = 100024;

    /**
     * token 失效
     */
    public static final Integer ERR_100025 = 100025;

    /**
     * 榜单不存在
     */
    public static final Integer ERR_100026 = 100026;


    /**
     * 没有修改权限
     */
    public static final Integer ERR_100027 = 100027;

    /**
     * 黑名单用户
     */
    public static final Integer ERR_100028 = 100028;
    /**
     * 门票校验失败-未配置扣积分变量
     */
    public static final Integer ERR_10029 = 100029;
    /**
     * 门票校验失败-未配置扣积分值
     */
    public static final Integer ERR_10030 = 100030;
    /**
     * 道具不存在
     */
    public static final Integer ERR_10031 = 100031;
    /**
     * 道具不存在
     */
    public static final Integer ERR_10032 = 100032;
    /**
     * 请求参数类型错误
     */
    public static final Integer ERR_10033 = 100033;
    /**
     * 请求参数不能为空
     */
    public static final Integer ERR_10034 = 100034;


    /**
     * 接口顺序访问拦截
     */
    public static final Integer ERR_10050 = 100050;


    /**
     * 未获取到用户并发锁,系统繁忙
     */
    public static final Integer ERR_10060 = 100060;

    /**
     * 请求参数错误
     */
    public static final Integer ERR_10061 = 100061;
    /**
     * 计数自增失败
     */
    public static final Integer ERR_100062 = 100062;
    /**
     * 保存标识失败
     */
    public static final Integer ERR_100063 = 100063;


    /** =============== Component part start =================== */
    /**
     * 组件玩法配置记录不存在
     */
    public static final Integer ERR_20000 = 200000;
    /**
     * 组件玩法config不存在
     */
    public static final Integer ERR_20001 = 200001;
    /**
     * 组件玩法options不存在
     */
    public static final Integer ERR_20002 = 200002;
    /**
     * 组件玩法配置解析异常异常
     */
    public static final Integer ERR_20003 = 200003;
    /**
     * 组件玩法未开始
     */
    public static final Integer ERR_20004 = 200004;
    /**
     * 组件玩法已结束
     */
    public static final Integer ERR_20005 = 200005;
    /**
     * 组件玩法已删除
     */
    public static final Integer ERR_20006 = 200006;
    /**
     * 组件玩法配置错误
     */
    public static final Integer ERR_20007 = 200007;

    /** =============== Exchange Component  =================== */
    /**
     * 不在规定时间内
     */
    public static final Integer ERR_200100 = 200100;
    /**
     * 兑换道具缺失
     */
    public static final Integer ERR_200101 = 200101;
    /**
     * 单用户该兑换组件下兑换次数超限
     */
    public static final Integer ERR_200102 = 200102;
    /**
     * 单用户该兑换组件下发奖规则兑换次数超限
     */
    public static final Integer ERR_200103 = 200103;
    /**
     * 奖品库存不足
     */
    public static final Integer ERR_200104 = 200104;
    /**
     * 未配置消耗的道具信息
     */
    public static final Integer ERR_200105 = 200105;


    /** =============== 分享组件  =================== */
    /**
     * 保存发奖标识失败
     */
    public static final Integer ERR_200200 = 200200;
    /**
     * 已经发奖
     */
    public static final Integer ERR_200201 = 200201;
    /**
     * 未分享过,不能发奖
     */
    public static final Integer ERR_200202 = 200202;
    /**
     * 增加次数失败
     */
    public static final Integer ERR_200203 = 200203;


    /** =============== 邀请助力组件  =================== */
    /**
     * 新老用户未配置
     */
    public static final Integer ERR_200300 = 200300;
    /**
     * 新用户不能助力
     */
    public static final Integer ERR_200301 = 200301;
    /**
     * 老用户不能助力
     */
    public static final Integer ERR_200302 = 200302;
    /**
     * 助力者助力次数已用完
     */
    public static final Integer ERR_200303 = 200303;
    /**
     * 被助力者已达到助力次数
     */
    public static final Integer ERR_200304 = 200304;
    /**
     * 给当前用户的助力次数已用完
     */
    public static final Integer ERR_200305 = 200305;
    /**
     * 不能为自己助力
     */
    public static final Integer ERR_200306 = 200306;
    /**
     * 保存邀请助力记录失败
     */
    public static final Integer ERR_200307 = 200307;
    /**
     * 邀请码不存在
     */
    public static final Integer ERR_200308 = 200308;

    /** =============== Countdown Component  =================== */
    /**
     * 不满足领取条件
     */
    public static final Integer ERR_200400 = 200400;
    /**
     * 倒计时配置异常
     */
    public static final Integer ERR_200401 = 200401;

    /** =============== 有效期组件  =================== */
    /**
     * 未参与
     */
    public static final Integer ERR_200501 = 200501;
    /**
     * 已经发奖
     */
    public static final Integer ERR_200503 = 200503;
    /**
     * 延迟领取时间不能超过3分钟
     */
    public static final Integer ERR_200504 = 200504;

    /** =============== 签到组件  =================== */
    /**
     * 已经签到
     */
    public static final Integer ERR_200601 = 200601;
    /**
     * 未签到
     */
    public static final Integer ERR_200602 = 200602;
    /**
     * 已经发奖
     */
    public static final Integer ERR_200603 = 200603;
    /**
     * 获取用户周期错误
     */
    public static final Integer ERR_200604 = 200604;
    /**
     * 签到奖励配置错误
     */
    public static final Integer ERR_200605 = 200605;

    /** =============== grade Component  =================== */
    /**
     * 获取用户等级错误
     */
    public static final Integer ERR_200700 = 200700;
    /**
     * 等级奖品已经领取
     */
    public static final Integer ERR_200701 = 200701;
    /**
     * 经验值不能小于0
     */
    public static final Integer ERR_200703 = 200703;
    /**
     * 等级配置错误
     */
    public static final Integer ERR_200704 = 200704;
    /**
     * 等级未配置奖品
     */
    public static final Integer ERR_200705 = 200705;
    /**
     * 未达到等级
     */
    public static final Integer ERR_200706 = 200706;

    /** =============== Bindphone Component  =================== */
    /**
     * 手机号格式不对
     */
    public static final Integer ERR_200800 = 200800;
    /**
     * 重复绑定已达上限
     */
    public static final Integer ERR_200801 = 200801;
    /**
     * 已绑定手机号，请勿重复绑定
     */
    public static final Integer ERR_200802 = 200802;
    /**
     * 当前手机号已被绑定，请换个手机号重试
     */
    public static final Integer ERR_200803 = 200803;
    /**
     * 归属地校验失败
     */
    public static final Integer ERR_200804 = 200804;
    /**
     * 当前手机号正在被绑定
     */
    public static final Integer ERR_200805 = 200805;
    /**
     * 信息发送失败
     */
    public static final Integer ERR_200806 = 200806;
    /**
     * 需要滑块校验
     */
    public static final Integer ERR_200807 = 200807;
    /**
     * 无响应
     */
    public static final Integer ERR_200808 = 200808;
    /**
     * 验证码校验失败
     */
    public static final Integer ERR_200809 = 200809;
    /**
     * 重复发送已达上限
     */
    public static final Integer ERR_200810 = 200810;

    /** =============== newGuide Component  =================== */
    /**
     * 新手引导已完成
     */
    public static final Integer ERR_200900 = 200900;
    /**
     * 新手引导暂不支持跳过
     */
    public static final Integer ERR_200901 = 200901;
    /**
     * 还有奖励未领取，不可以跳过引导教程
     */
    public static final Integer ERR_200902 = 200902;

    /** =============== task Component  =================== */
    /**
     * 获取任务配置错误
     */
    public static final Integer ERR_201000 = 201000;
    /**
     * 任务已完成
     */
    public static final Integer ERR_201001 = 201001;
    /**
     * 任务未完成
     */
    public static final Integer ERR_201003 = 201003;
    /**
     * 任务奖励已领取
     */
    public static final Integer ERR_201004 = 201004;
    /**
     * 增加任务完成次数失败
     */
    public static final Integer ERR_201005 = 201005;

    /** =============== collect sp Component  =================== */
    /**
     * 该玩法不包含此道具
     */
    public static final Integer ERR_201100 = 201100;
    /**
     * 保存赠送道具记录失败
     */
    public static final Integer ERR_201101 = 201101;
    /**
     * 赠送道具记录不存在
     */
    public static final Integer ERR_201102 = 201102;
    /**
     * 接收道具失败
     */
    public static final Integer ERR_201103 = 201103;
    /**
     * 道具已赠送
     */
    public static final Integer ERR_201104 = 201104;
    /**
     * 消耗道具失败
     */
    public static final Integer ERR_201105 = 201105;
    /**
     * 不能领取自己赠送的道具
     */
    public static final Integer ERR_201106 = 201106;

    /** =============== pending Component  =================== */
    /**
     * 待操作记录插入失败
     */
    public static final Integer ERR_201200 = 201200;
    /**
     * 待操作记录更新为已完成失败
     */
    public static final Integer ERR_201201 = 201201;
    /**
     * 待操作记录不存在
     */
    public static final Integer ERR_201203 = 201203;

    /** =============== participate Component  =================== */
    /**
     * 该玩法不包含此道具
     */
    public static final Integer ERR_201300 = 201300;
    /**
     * 次数已用完
     */
    public static final Integer ERR_201301 = 201301;
    /**
     * 增加次数失败
     */
    public static final Integer ERR_201302 = 201302;
    /**
     * 积分门票错误
     */
    public static final Integer ERR_201303 = 201303;
    /**
     * 积分数量错误
     */
    public static final Integer ERR_201304 = 201304;
    /**
     * 使用积分门票失败
     */
    public static final Integer ERR_201305 = 201305;
    /**
     * 消耗道具失败
     */
    public static final Integer ERR_201306 = 201306;

    /** =============== rank Component  =================== */
    /**
     * 排行榜提交分数超过最大值
     */
    public static final Integer ERR_201400 = 201400;

    /** =============== answer Component  =================== */
    /**
     * 保存答题记录失败
     */
    public static final Integer ERR_201501 = 201501;
    /**
     * 答题记录不存在
     */
    public static final Integer ERR_201502 = 201502;
    /**
     * 本次答题已结束
     */
    public static final Integer ERR_201503 = 201503;
    /**
     * 未配置题目
     */
    public static final Integer ERR_201504 = 201504;
    /**
     * 答题状态解析错误
     */
    public static final Integer ERR_201505 = 201505;
    /**
     * 题目已出完
     */
    public static final Integer ERR_201506 = 201506;
    /**
     * 保存答题状态失败
     */
    public static final Integer ERR_201507 = 201507;
    /**
     * 获取题目失败
     */
    public static final Integer ERR_201508 = 201508;
    /**
     * 本次答题时间已结束
     */
    public static final Integer ERR_201509 = 201509;
    /**
     * 先获取题目
     */
    public static final Integer ERR_201510 = 201510;
    /**
     * 本题答题时间已结束
     */
    public static final Integer ERR_201511 = 201511;
    /**
     * 支持单选题目
     */
    public static final Integer ERR_201512 = 201512;
    /**
     * 已经是最后一题
     */
    public static final Integer ERR_201513 = 201513;
    /**
     * 已经提交
     */
    public static final Integer ERR_201514 = 201514;

    /** =============== tmrAward Component  =================== */
    /**
     * 不在有效期内
     */
    public static final Integer ERR_201600 = 201600;
    /**
     * 非法的领取行为
     */
    public static final Integer ERR_201601 = 201601;
    /**
     * 收益已被领取
     */
    public static final Integer ERR_201602 = 201602;


    /** =============== Component part end =================== */
}

==> projectx-sdk-1.0.78-sources.jar: cn/com/duiba/projectx/sdk/ErrorCode.java <==
package cn.com.duiba.projectx.sdk;

public class ErrorCode {

    /**
     * 未知异常
     */
    public static final Integer ERR_10000 = 100000;
    public static final String ERR_10000_MSG = "未知异常";
    /**
     * 未登录
     */
    public static final Integer ERR_10001 = 100001;
    /**
     * 活动未开始
     */
    public static final Integer ERR_10002 = 100002;
    /**
     * 活动已结束
     */
    public static final Integer ERR_10003 = 100003;
    /**
     * 活动异常
     */
    public static final Integer ERR_10004 = 100004;
    /**
     * 前置校验失败
     */
    public static final Integer ERR_10005 = 100005;
    /**
     * 门票校验失败
     */
    public static final Integer ERR_10006 = 100006;
    /**
     * 无权访问，定向APP
     */
    public static final Integer ERR_10007 = 100007;
    /**
     * Not Found
     */
    public static final Integer ERR_10008 = 100008;

    /**
     * 不允许openBs访问
     */
    public static final Integer ERR_10009 = 100009;

    /**
     * 生成邀请码失败
     */
    public static final Integer ERR_10010 = 100010;

    /**
     * 邀请码不存在
     */
    public static final Integer ERR_10011 = 100011;

    /**
     * 已经接受邀请
     */
    public static final Integer ERR_10012 = 100012;

    /**
     * 邀请码异常
     */
    public static final Integer ERR_10013 = 100013;

    /**
     * 不能邀请自己
     */
    public static final Integer ERR_10014 = 100014;

    /**
     * 已经过接受邀请
     */
    public static final Integer ERR_10015 = 100015;

    /**
     * 库存限制
     */
    public static final Integer ERR_10016 = 100016;

    /**
     * 参数校验失败
     */
    public static final Integer ERR_10017 = 100017;

    /**
     * 风控异常
     */
    public static final Integer ERR_10018 = 100018;

    /**
     * 非法助力itemId
     */
    public static final Integer ERR_10019 = 100019;

    /**
     * 不能给自己助力
     */
    public static final Integer ERR_100020 = 100020;

    /**
     * 方法不存在
     */
    public static final Integer ERR_10021 = 100021;

    /**
     * Token为空
     */
    public static final Integer ERR_100022 = 100022;

    /**
     * 无效Token
     */
    public static final Integer ERR_100023 = 100023;

    /**
     * token key失效
     */
    public static final Integer ERR_100024 = 100024;

    /**
     * token 失效
     */
    public static final Integer ERR_100025 = 100025;

    /**
     * 榜单不存在
     */
    public static final Integer ERR_100026 = 100026;


    /**
     * 没有修改权限
     */
    public static final Integer ERR_100027 = 100027;

    /**
     * 黑名单用户
     */
    public static final Integer ERR_100028 = 100028;
    /**
     * 门票校验失败-未配置扣积分变量
     */
    public static final Integer ERR_10029 = 100029;
    /**
     * 门票校验失败-未配置扣积分值
     */
    public static final Integer ERR_10030 = 100030;
    /**
     * 道具不存在
     */
    public static final Integer ERR_10031 = 100031;
    /**
     * 道具不存在
     */
    public static final Integer ERR_10032 = 100032;
    /**
     * 请求参数类型错误
     */
    public static final Integer ERR_10033 = 100033;
    /**
     * 请求参数不能为空
     */
    public static final Integer ERR_10034 = 100034;


    /**
     * 接口顺序访问拦截
     */
    public static final Integer ERR_10050 = 100050;


    /**
     * 未获取到用户并发锁,系统繁忙
     */
    public static final Integer ERR_10060 = 100060;

    /**
     * 请求参数错误
     */
    public static final Integer ERR_10061 = 100061;
    /**
     * 计数自增失败
     */
    public static final Integer ERR_100062 = 100062;
    /**
     * 保存标识失败
     */
    public static final Integer ERR_100063 = 100063;


    /** =============== Component part start =================== */
    /**
     * 组件玩法配置记录不存在
     */
    public static final Integer ERR_20000 = 200000;
    /**
     * 组件玩法config不存在
     */
    public static final Integer ERR_20001 = 200001;
    /**
     * 组件玩法options不存在
     */
    public static final Integer ERR_20002 = 200002;
    /**
     * 组件玩法配置解析异常异常
     */
    public static final Integer ERR_20003 = 200003;
    /**
     * 组件玩法未开始
     */
    public static final Integer ERR_20004 = 200004;
    /**
     * 组件玩法已结束
     */
    public static final Integer ERR_20005 = 200005;
    /**
     * 组件玩法已删除
     */
    public static final Integer ERR_20006 = 200006;
    /**
     * 组件玩法配置错误
     */
    public static final Integer ERR_20007 = 200007;
    /**
     * 奖励次数值配置错误
     */
    public static final Integer ERR_20008 = 200008;

    /** =============== exchange Component  =================== */
    /**
     * 不在规定时间内
     */
    public static final Integer ERR_200100 = 200100;
    /**
     * 兑换道具缺失
     */
    public static final Integer ERR_200101 = 200101;
    /**
     * 单用户该兑换组件下兑换次数超限
     */
    public static final Integer ERR_200102 = 200102;
    /**
     * 单用户该兑换组件下发奖规则兑换次数超限
     */
    public static final Integer ERR_200103 = 200103;
    /**
     * 奖品库存不足
     */
    public static final Integer ERR_200104 = 200104;
    /**
     * 未配置消耗的道具信息
     */
    public static final Integer ERR_200105 = 200105;


    /** =============== share Component  =================== */
    /**
     * 保存发奖标识失败
     */
    public static final Integer ERR_200200 = 200200;
    /**
     * 已经发奖
     */
    public static final Integer ERR_200201 = 200201;
    /**
     * 未分享过,不能发奖
     */
    public static final Integer ERR_200202 = 200202;
    /**
     * 增加次数失败
     */
    public static final Integer ERR_200203 = 200203;


    /** =============== inviteAssist Component  =================== */
    /**
     * 新老用户未配置
     */
    public static final Integer ERR_200300 = 200300;
    /**
     * 新用户不能助力
     */
    public static final Integer ERR_200301 = 200301;
    /**
     * 老用户不能助力
     */
    public static final Integer ERR_200302 = 200302;
    /**
     * 助力者助力次数已用完
     */
    public static final Integer ERR_200303 = 200303;
    /**
     * 被助力者已达到助力次数
     */
    public static final Integer ERR_200304 = 200304;
    /**
     * 给当前用户的助力次数已用完
     */
    public static final Integer ERR_200305 = 200305;
    /**
     * 不能为自己助力
     */
    public static final Integer ERR_200306 = 200306;
    /**
     * 保存邀请助力记录失败
     */
    public static final Integer ERR_200307 = 200307;
    /**
     * 邀请码不存在
     */
    public static final Integer ERR_200308 = 200308;

    /** =============== countdown Component  =================== */
    /**
     * 不满足领取条件
     */
    public static final Integer ERR_200400 = 200400;
    /**
     * 倒计时配置异常
     */
    public static final Integer ERR_200401 = 200401;

    /** =============== period Component  =================== */
    /**
     * 未参与
     */
    public static final Integer ERR_200501 = 200501;
    /**
     * 已经发奖
     */
    public static final Integer ERR_200503 = 200503;
    /**
     * 延迟领取时间不能超过3分钟
     */
    public static final Integer ERR_200504 = 200504;

    /** =============== checkin Component  =================== */
    /**
     * 已经签到
     */
    public static final Integer ERR_200601 = 200601;
    /**
     * 未签到
     */
    public static final Integer ERR_200602 = 200602;
    /**
     * 已经发奖
     */
    public static final Integer ERR_200603 = 200603;
    /**
     * 获取用户周期错误
     */
    public static final Integer ERR_200604 = 200604;
    /**
     * 签到奖励配置错误
     */
    public static final Integer ERR_200605 = 200605;

    /** =============== grade Component  =================== */
    /**
     * 获取用户等级错误
     */
    public static final Integer ERR_200700 = 200700;
    /**
     * 等级奖品已经领取
     */
    public static final Integer ERR_200701 = 200701;
    /**
     * 经验值不能小于0
     */
    public static final Integer ERR_200703 = 200703;
    /**
     * 等级配置错误
     */
    public static final Integer ERR_200704 = 200704;
    /**
     * 等级未配置奖品
     */
    public static final Integer ERR_200705 = 200705;
    /**
     * 未达到等级
     */
    public static final Integer ERR_200706 = 200706;

    /** =============== bindPhone Component  =================== */
    /**
     * 手机号格式不对
     */
    public static final Integer ERR_200800 = 200800;
    /**
     * 重复绑定已达上限
     */
    public static final Integer ERR_200801 = 200801;
    /**
     * 已绑定手机号，请勿重复绑定
     */
    public static final Integer ERR_200802 = 200802;
    /**
     * 当前手机号已被绑定，请换个手机号重试
     */
    public static final Integer ERR_200803 = 200803;
    /**
     * 归属地校验失败
     */
    public static final Integer ERR_200804 = 200804;
    /**
     * 当前手机号正在被绑定
     */
    public static final Integer ERR_200805 = 200805;
    /**
     * 信息发送失败
     */
    public static final Integer ERR_200806 = 200806;
    /**
     * 需要滑块校验
     */
    public static final Integer ERR_200807 = 200807;
    /**
     * 无响应
     */
    public static final Integer ERR_200808 = 200808;
    /**
     * 验证码校验失败
     */
    public static final Integer ERR_200809 = 200809;
    /**
     * 重复发送已达上限
     */
    public static final Integer ERR_200810 = 200810;

    /** =============== newGuide Component  =================== */
    /**
     * 新手引导已完成
     */
    public static final Integer ERR_200900 = 200900;
    /**
     * 新手引导暂不支持跳过
     */
    public static final Integer ERR_200901 = 200901;
    /**
     * 还有奖励未领取，不可以跳过引导教程
     */
    public static final Integer ERR_200902 = 200902;

    /** =============== task Component  =================== */
    /**
     * 获取任务配置错误
     */
    public static final Integer ERR_201000 = 201000;
    /**
     * 任务已完成
     */
    public static final Integer ERR_201001 = 201001;
    /**
     * 任务未完成
     */
    public static final Integer ERR_201003 = 201003;
    /**
     * 任务奖励已领取
     */
    public static final Integer ERR_201004 = 201004;
    /**
     * 增加任务完成次数失败
     */
    public static final Integer ERR_201005 = 201005;
    /**
     * 任务ID和领奖CODE不匹配
     */
    public static final Integer ERR_201006 = 201006;

    /** =============== collectSp Component  =================== */
    /**
     * 该玩法不包含此道具
     */
    public static final Integer ERR_201100 = 201100;
    /**
     * 保存赠送道具记录失败
     */
    public static final Integer ERR_201101 = 201101;
    /**
     * 赠送道具记录不存在
     */
    public static final Integer ERR_201102 = 201102;
    /**
     * 接收道具失败
     */
    public static final Integer ERR_201103 = 201103;
    /**
     * 道具已赠送
     */
    public static final Integer ERR_201104 = 201104;
    /**
     * 消耗道具失败
     */
    public static final Integer ERR_201105 = 201105;
    /**
     * 不能领取自己赠送的道具
     */
    public static final Integer ERR_201106 = 201106;

    /** =============== pending Component  =================== */
    /**
     * 待操作记录插入失败
     */
    public static final Integer ERR_201200 = 201200;
    /**
     * 待操作记录更新为已完成失败
     */
    public static final Integer ERR_201201 = 201201;
    /**
     * 待操作记录不存在
     */
    public static final Integer ERR_201203 = 201203;

    /** =============== participate Component  =================== */
    /**
     * 该玩法不包含此道具
     */
    public static final Integer ERR_201300 = 201300;
    /**
     * 次数已用完
     */
    public static final Integer ERR_201301 = 201301;
    /**
     * 增加次数失败
     */
    public static final Integer ERR_201302 = 201302;
    /**
     * 积分门票错误
     */
    public static final Integer ERR_201303 = 201303;
    /**
     * 积分数量错误
     */
    public static final Integer ERR_201304 = 201304;
    /**
     * 使用积分门票失败
     */
    public static final Integer ERR_201305 = 201305;
    /**
     * 消耗道具失败
     */
    public static final Integer ERR_201306 = 201306;

    /** =============== rank Component  =================== */
    /**
     * 排行榜提交分数超过最大值
     */
    public static final Integer ERR_201400 = 201400;

    /** =============== answer Component  =================== */
    /**
     * 保存答题记录失败
     */
    public static final Integer ERR_201501 = 201501;
    /**
     * 答题记录不存在
     */
    public static final Integer ERR_201502 = 201502;
    /**
     * 本次答题已结束
     */
    public static final Integer ERR_201503 = 201503;
    /**
     * 未配置题目
     */
    public static final Integer ERR_201504 = 201504;
    /**
     * 答题状态解析错误
     */
    public static final Integer ERR_201505 = 201505;
    /**
     * 题目已出完
     */
    public static final Integer ERR_201506 = 201506;
    /**
     * 保存答题状态失败
     */
    public static final Integer ERR_201507 = 201507;
    /**
     * 获取题目失败
     */
    public static final Integer ERR_201508 = 201508;
    /**
     * 本次答题时间已结束
     */
    public static final Integer ERR_201509 = 201509;
    /**
     * 先获取题目
     */
    public static final Integer ERR_201510 = 201510;
    /**
     * 本题答题时间已结束
     */
    public static final Integer ERR_201511 = 201511;
    /**
     * 支持单选题目
     */
    public static final Integer ERR_201512 = 201512;
    /**
     * 已经是最后一题
     */
    public static final Integer ERR_201513 = 201513;
    /**
     * 已经提交
     */
    public static final Integer ERR_201514 = 201514;

    /** =============== tmrAward Component  =================== */
    /**
     * 不在有效期内
     */
    public static final Integer ERR_201600 = 201600;
    /**
     * 非法的领取行为
     */
    public static final Integer ERR_201601 = 201601;
    /**
     * 收益已被领取
     */
    public static final Integer ERR_201602 = 201602;

    /** =============== team Component  =================== */
    /**
     * 保存队伍失败
     */
    public static final Integer ERR_201700 = 201700;
    /**
     * 队伍不存在
     */
    public static final Integer ERR_201701 = 201701;
    /**
     * 没有加入队伍
     */
    public static final Integer ERR_201702 = 201702;
    /**
     * 删除队员失败
     */
    public static final Integer ERR_201703 = 201703;
    /**
     * 更新队伍人数失败
     */
    public static final Integer ERR_201704 = 201704;
    /**
     * 保存队伍到记录表失败
     */
    public static final Integer ERR_201705 = 201705;
    /**
     * 删除队伍失败
     */
    public static final Integer ERR_201706 = 201706;
    /**
     * 更新为队员失败
     */
    public static final Integer ERR_201707 = 201707;
    /**
     * 更新为队长失败
     */
    public static final Integer ERR_201708 = 201708;
    /**
     * 该队伍没有队员
     */
    public static final Integer ERR_201709 = 201709;
    /**
     * 更新队员分数失败
     */
    public static final Integer ERR_201710 = 201710;
    /**
     * 更新队伍分数失败
     */
    public static final Integer ERR_201711 = 201711;
    /**
     * 队伍已经满员
     */
    public static final Integer ERR_201712 = 201712;
    /**
     * 已经加入了其他队伍
     */
    public static final Integer ERR_201713 = 201713;
    /**
     * 已经加入了该队伍
     */
    public static final Integer ERR_201714 = 201714;
    /**
     * 保存队员信息失败
     */
    public static final Integer ERR_201715 = 201715;
    /**
     * 更新队伍满员时间
     */
    public static final Integer ERR_201716 = 201716;
    /**
     * 删除用户队伍失败
     */
    public static final Integer ERR_201717 = 201717;

    /** =============== collectAward Component  =================== */
    /**
     * 道具不充足
     */
    public static final Integer ERR_201800 = 201800;
    /**
     * 兑奖次数超限
     */
    public static final Integer ERR_201801 = 201801;



    /** =============== Component part end =================== */
}
